========================
Team and repository tags
========================

======
os-acc
======

A library for attaching and detaching accelerators in OpenStack.

* License: Apache License, Version 2.0
* Documentation:
* Source:
* Bugs:
* Release Notes:
